=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2005-10-06 12:03:56 +0000
+++ bzrlib/commit.py	2005-10-06 22:55:44 +0000
@@ -192,7 +192,10 @@
         else:
             self.timezone = int(timezone)
 
-        assert isinstance(message, basestring), type(message)
+        if isinstance(message, str):
+            import bzrlib
+            message = message.decode(bzrlib.user_encoding)
+        assert isinstance(message, unicode), type(message)
         self.message = message
         self._escape_commit_message()
 
@@ -241,14 +244,8 @@
         # represented in well-formed XML; escape characters that
         # aren't listed in the XML specification
         # (http://www.w3.org/TR/REC-xml/#NT-Char).
-        if isinstance(self.message, unicode):
-            char_pattern = u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]'
-        else:
-            # Use a regular 'str' as pattern to avoid having re.subn
-            # return 'unicode' results.
-            char_pattern = '[^\x09\x0A\x0D\x20-\xFF]'
         self.message, escape_count = re.subn(
-            char_pattern,
+            u'[^\x09\x0A\x0D\u0020-\uD7FF\uE000-\uFFFD]+',
             lambda match: match.group(0).encode('unicode_escape'),
             self.message)
         if escape_count:

=== modified file 'bzrlib/selftest/testlog.py'
--- bzrlib/selftest/testlog.py	2005-10-02 21:51:29 +0000
+++ bzrlib/selftest/testlog.py	2005-10-06 22:55:44 +0000
@@ -153,6 +153,7 @@
         
         # commit a log message with control characters
         msg = "All 8-bit chars: " +  ''.join([unichr(x) for x in range(256)])
+        self.log("original commit message: %r", msg)
         b.commit(msg)
         lf = LogCatcher()
         show_log(b, lf, verbose=True)
@@ -160,3 +161,17 @@
         self.log("escaped commit message: %r", committed_msg)
         self.assert_(msg != committed_msg)
         self.assert_(len(committed_msg) > len(msg))
+
+        # Check that log message with only XML-valid characters isn't
+        # escaped.  As ElementTree apparently does some kind of
+        # newline conversion, neither LF (\x0A) nor CR (\x0D) are
+        # included in the test commit message, even though they are
+        # valid XML 1.0 characters.
+        msg = "\x09" + ''.join([unichr(x) for x in range(0x20, 256)])
+        self.log("original commit message: %r", msg)
+        b.commit(msg)
+        lf = LogCatcher()
+        show_log(b, lf, verbose=True)
+        committed_msg = lf.logs[0].rev.message
+        self.log("escaped commit message: %r", committed_msg)
+        self.assert_(msg == committed_msg)

